@@ -31,13 +31,10 @@ SOFTWARE.
 import re
 import time
 
-from bs4 import BeautifulSoup
-import requests
+from .utils import get_soup, get_item_soup
+from .constants import BASE_URL, INTERVAL_BETWEEN_REQUESTS
 
 
-BASE_URL = 'https://news.ycombinator.com'
-INTERVAL_BETWEEN_REQUESTS = 1 # seconds to sleep between 2 consecutive page requests
-
 class HN(object):
     """
     The class that parses the HN page, and builds up all stories
@@ -62,13 +59,13 @@ class HN(object):
         \tpage_limit=1 implies just the top level page
         """
         soups = list() # will hold all soups
-        soups.append(self._get_soup(page)) # get the first page
+        soups.append(get_soup(page)) # get the first page
 
         while len(soups) < page_limit:
             # get as manu pages as requested
             cur_soup = soups[-1] # get the last seen page's soup
             next_page = self._get_next_page(cur_soup).lstrip('//')
-            next_soup = self._get_soup(next_page) # get the next soup
+            next_soup = get_soup(next_page) # get the next soup
             if len(next_soup.findChildren('table')) != 0:
                 # making sure we are on the right page... get it?
                 soups.append(next_soup)
@@ -77,15 +74,6 @@ class HN(object):
             time.sleep(INTERVAL_BETWEEN_REQUESTS) # be a good citizen
         return soups
 
-
-    def _get_soup(self, page=''):
-        """
-        Returns a bs4 object of the page requested
-        """
-        content = requests.get('%s/%s' % (BASE_URL, page)).text
-        return BeautifulSoup(content)
-
-
     def _get_zipped_rows(self, soup):
         """
         Returns all 'tr' tag rows as a list of tuples. Each tuple is for
@@ -94,10 +82,7 @@ class HN(object):
         table = soup.findChildren('table')[2] # the table with all submissions
         rows = table.findChildren(['tr'])[:-2] # get all rows but last 2
         # remove the spacing rows
-        try:
-            spacing = xrange(2, len(rows), 3) # indices of spacing tr's
-        except:
-            spacing = range(2, len(rows), 3) # indices of spacing tr's python3
+        spacing = range(2, len(rows), 3) # indices of spacing tr's
         rows = [row for (i, row) in enumerate(rows) if (i not in spacing)]
         # rank, title, domain
         info = [row for (i, row) in enumerate(rows) if (i % 2 == 0)]
@@ -130,6 +115,7 @@ class HN(object):
                 is_self = True
             else:
                 domain = info_cells[2].find('span').string[2:-2] # slice " (abc.com) "
+                
             #-- Get the into about a story --#
 
             #-- Get the detail about a story --#
@@ -166,21 +152,10 @@ class HN(object):
                 comment_count = -1
             #-- Get the detail about a story --#
 
-            story = {
-                "rank": rank,
-                "story_id": story_id,
-                "title": title,
-                "link": link,
-                "domain": domain,
-                "points": points,
-                "submitter": submitter,
-                "published_time": published_time,
-                "submitter_profile": submitter_profile,
-                "num_comments": num_comments,
-                "comments_link": comments_link,
-                "is_self": is_self
-
-            }
+            story = Story(rank, story_id, title, link, domain, points, submitter, 
+                 published_time, submitter_profile, num_comments, comments_link,
+                 is_self)
+            
             all_stories.append(story)
         
         return all_stories
@@ -203,4 +178,104 @@ class HN(object):
             all_rows = self._get_zipped_rows(soup)
             story = story + self._build_story(all_rows)
 
-        return story
\ No newline at end of file
+        return story
+
+
+class Story(object):
+    """
+    Story class represents one single story on HN
+    """
+    
+    def __init__(self, rank, story_id, title, link, domain, points, submitter, 
+                published_time, submitter_profile, num_comments, comments_link,
+               is_self):
+        self.rank = rank # the rank of story on the page
+        self.story_id = story_id # the story's id
+        self.title = title.encode('cp850', errors='replace').decode('cp850') # the title of the story
+        self.link = link # the url it points to (None for self posts)
+        self.domain = domain # the domain of the link (None for self posts)
+        self.points = points # the points/karma on the story
+        self.submitter = submitter # the user who submitted the story
+        self.published_time = published_time # publish time of story
+        self.submitter_profile = submitter_profile # link to submitter's profile
+        self.num_comments = num_comments # the number of comments it has
+        self.comments_link = comments_link # the link to the comments page
+        self.is_self = is_self # Truw is a self post
+
+    def __repr__(self):
+        """
+        A string representation of the class object
+        """
+        return '<Story: ID={0}>'.format(self.story_id)
+    
+    def _build_comments(self, soup):
+        """
+        For the story, builds and returns a list of Comment objects.
+        """
+        table = soup.findChildren('table')[3] # the table holding all comments
+        rows = table.findChildren(['tr']) # get all rows (each comment is duplicated twice)
+        rows = [row for i, row in enumerate(rows) if (i % 2 == 0)] # now we have unique comments only
+        
+        comments = []
+        
+        if len(rows) > 1:
+            for row in rows:
+                
+                ## Builds a flat list of comments
+                
+                # level of comment, starting with 0
+                level = int(row.findChildren('td')[1].find('img').get('width')) // 40
+
+                spans = row.findChildren('td')[3].findAll('span')
+                # span[0] = submitter details
+                # [<a href="user?id=jonknee">jonknee</a>, u' 1 hour ago  | ', <a href="item?id=6910978">link</a>]
+                # span[1] = actual comment
+
+                if str(spans[0]) != '<span class="comhead"></span>':
+                    user = spans[0].contents[0].string # user who submitted the comment
+                    time_ago = spans[0].contents[1].string.strip().rstrip(' |') # relative time of comment
+                    comment_id = int(re.match(r'item\?id=(.*)', spans[0].contents[2].get('href')).groups()[0])
+                
+                    body = spans[1].text # text representation of comment (unformatted)
+                    # html of comment, may not be valid
+                    pat = re.compile(r'<span class="comment"><font color=".*">(.*)</font></span>')
+                    body_html = re.match(pat, str(spans[1]).replace('\n', '')).groups()[0]
+                else:
+                    # comment deleted
+                    user = ''
+                    time_ago = ''
+                    comment_id = -1
+                    body = '[deleted]'
+                    body_html = '[deleted]'
+
+                comment = Comment(comment_id, level, user, time_ago, body, body_html)
+                comments.append(comment)
+            
+        return comments
+        
+    def get_comments(self):
+        """
+        Returns a list of Comment(s) for the given story
+        """
+        soup = get_item_soup(self.story_id)
+        return self._build_comments(soup)
+
+
+class Comment(object):
+    """
+    Represents a comment on a post on HN
+    """
+    
+    def __init__(self, comment_id, level, user, time_ago, body, body_html):
+        self.comment_id = comment_id # the comment's item id
+        self.level = level # commen's nesting level
+        self.user = user # user's name who submitted the post
+        self.time_ago = time_ago # time when it was submitted
+        self.body = body.encode('cp850', errors='replace').decode('cp850') # text representation of comment (unformatted)
+        self.body_html = body_html # html of comment, may not be valid
+
+    def __repr__(self):
+        """
+        A string representation of the class object
+        """
+        return '<Comment: ID={0}>'.format(self.comment_id)
\ No newline at end of file
